﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
//-------------------------------------------------------------------------------
// (C) 2009-2017 CITIZEN SYSTEMS JAPAN CO., LTD. All Rights Reserved.
//-------------------------------------------------------------------------------
// Layout SDK (via Printer Driver), sample code [[ TestPrint ]] for VCS2010
//
// 本プログラムは､
// レイアウトファイルを利用した基本的な印刷サンプルコードです｡
// なお､エラー処理が行われていないことをご了承ください｡
//
// 印刷に必要なコマンドの手順は以下のようになります。
//
// [01] オブジェクトを生成.                              CreateObject あるいは、 New
// [02] レイアウトファイルをオープン.                    Open
// [03] オブジェクトを初期化.                            BeginPrint
// [04] 指定フレームのインデックスを取得.                InitFrame
// [05] 指定フレーム内の指定部品のインデックスを取得.    GetParts
// [06] オブジェクト内ワークエリアを変更.                SetPartsData
// [07] オブジェクト内ワークエリアを印刷エリアへコピー.  AddFrame
// [08] 印刷開始.                                        DoPrint
// [09] オブジェクト内ワークエリアを破棄.                EndPrint
// [10] オブジェクト内の全ての領域をクリア.              Close
namespace TestPrint
{
	public partial class Form1 : Form
	{
		public Form1()
		{
			InitializeComponent();
		}

		private void Form1_Load(object sender, EventArgs e)
		{
			//-------------------------------------------------------------------------------
			// OS にインストールされているプリンタ名を全て取得
			//-------------------------------------------------------------------------------
			foreach (string printerName in System.Drawing.Printing.PrinterSettings.InstalledPrinters)
			{
				comboBox1.Items.Add(printerName);

				//-------------------------------------------------------------------------------
				// CITIZEN プリンターを選択
				//-------------------------------------------------------------------------------
				if ((0 > comboBox1.SelectedIndex) &&
					(0 <= printerName.ToUpper().IndexOf("CITIZEN")))
				{
					comboBox1.SelectedIndex = comboBox1.Items.Count - 1;
				}
			}
			//-------------------------------------------------------------------------------
			// 初回印刷の高速化
			//-------------------------------------------------------------------------------
			preparePrint(textBox1.Text);
		}

		private void button1_Click(object sender, EventArgs e)
		{
			//-------------------------------------------------------------------------------
			// レイアウトファイルの選択
			//-------------------------------------------------------------------------------
            OpenFileDialog ofd = new OpenFileDialog();
            ofd.InitialDirectory = @"..\..\";
            ofd.RestoreDirectory = true;
            ofd.Title = "Open a CLF file";
            ofd.Filter = "CLF files (*.clf)|*.clf";
            ofd.FileName = "";
            if (ofd.ShowDialog() == DialogResult.OK)
            {
                textBox1.Text = ofd.FileName;
				//-------------------------------------------------------------------------------
				// 初回印刷の高速化
				//-------------------------------------------------------------------------------
				preparePrint(textBox1.Text);
			}
		}

		private void button2_Click(object sender, EventArgs e)
		{
			//-----------------------------------------------------------------
			// 準備
			//-----------------------------------------------------------------
			// [01] オブジェクトの生成.
			Citizen.LayoutUtilities.Printing.Controller clpc = new Citizen.LayoutUtilities.Printing.Controller();

			// [02] レイアウトファイルをオープン.
			//      引数：パス名
			int result = clpc.Open(textBox1.Text);

			// [03] オブジェクトの初期化.
			//      InitFrame() 関数, AddFrame() 関数らの結果を初期化.
			//      引数：なし
			clpc.BeginPrint();

			//-----------------------------------------------------------------
			// Frame1 の Text1 を変更して、印刷エリアへ追加
			//-----------------------------------------------------------------
			// [04] 指定フレームのインデックスを取得.
			//      指定フレームをオブジェクト内ワークエリアへコピー.
			//      引数：フレーム名
			int frameIndex = clpc.InitFrame("Frame1");

			// [05] 指定フレーム内の指定部品のインデックスを取得.
			//      引数：フレームインデックス, 部品名
			int partsIndex = clpc.GetParts(frameIndex, "Text1");

			// [06] オブジェクト内ワークエリアを変更.
			//      引数：フレームインデックス, 部品インデックス, データ
			result = clpc.SetPartsData(frameIndex, partsIndex, textBox2.Text);

			// [07] オブジェクト内ワークエリアを印刷エリアへコピー.
			//      この処理の前に InitFrame() 関数が処理されている必要があります。
			//      引数：フレームインデックス
			result = clpc.AddFrame(frameIndex);

			//-----------------------------------------------------------------
			// 印刷エリアのデータを印刷
			//-----------------------------------------------------------------
			// [08] 印刷開始.
			//      DoPrint() 関数実行前に AddFrame() 関数が実行されている必要があります。
			//      引数：プリンタ名 (ブランクの場合、OS デフォルト プリンタ)
			result = clpc.DoPrint(comboBox1.Text);

			//-----------------------------------------------------------------
			// 終了
			//-----------------------------------------------------------------
			// [09] オブジェクト内ワークエリアの破棄.
			//      EndPrint() 関数実行後は、BeginPrint() 関数、または Close() 関数、のいずれかを行ってください。
			//      引数：なし
			clpc.EndPrint();

			// [10] オブジェクト内の全ての領域をクリア.
			//      Close() 関数実行後は、Open() 関数以外は実行できません。
			//      引数：なし
			clpc.Close();
		}

		//-----------------------------------------------------------------
		// 初回印刷を高速化します
		//-----------------------------------------------------------------
		private void preparePrint(string pathName)
		{
			Citizen.LayoutUtilities.Printing.Controller clpc = new Citizen.LayoutUtilities.Printing.Controller();
			int result = clpc.PreparePrint(pathName);
//			int result = clpc.HidePreview(pathName);
		}
	}
}
